@@ -9,8 +9,21 @@
   keys   <- sample(seq(0, 1, by=.2))
   values <- paste0("V", keys)
   fheap  <- insert(fheap, keys, values)
+  
   size(fheap)
 
+## ------------------------------------------------------------------------
+  fheap  <- insert(fheap, -1, letters)
+  peek(fheap)
+
+## ------------------------------------------------------------------------
+  fheap  <- insert(fheap, c(-2, -3), matrix(letters, 2))
+  peek(fheap)
+
+## ------------------------------------------------------------------------
+  fheap  <- insert(fheap, c(-4, -5), list("a", letters[1:4]))
+  peek(fheap)
+
 ## ------------------------------------------------------------------------
   peek(fheap)
   size(fheap)
@@ -20,7 +33,7 @@
   size(fheap)
 
 ## ------------------------------------------------------------------------
-  fheap[-1] <- "V-1"
+  fheap[-10] <- "V-1"
   peek(fheap)
 
 ## ------------------------------------------------------------------------
@@ -63,7 +76,7 @@
   peek(st)
 
 ## ------------------------------------------------------------------------
-  size(qu)
-  pop(qu)
-  size(qu)
+  st <- insert(st, list(1, rnorm(5)))
+  pop(st)
+  pop(st)
 
